class Moon extends SpaceObject {
	Planet planetAbout;

	/**
	*	Create a moon using drawSolarObjectAbout with the passed 
	*	parameters. drawSolarObjectAbout is populated with the
	*	passed planet's distance and angle (planetAbout)
	*
	*	Instead of passing a velocity relative to earth into 
	*	the moon, a sidereal period is passed instead (easier
	*	to find on the web). This value is then converted to a 
	*	velocity that is relative to Earth's. This makes for 
	*	easier initialisation of moons
	*/
	public Moon(SolarSystem solarSystem, Planet planetAbout, double distance, double diameter, double sidereal, String colour) {
		super(solarSystem, distance, diameter, sidereal/(365/planetAbout.velocity), colour);
		this.planetAbout = planetAbout;

		this.solarSystem.drawSolarObjectAbout(planetAbout.distance, planetAbout.angle, diameter, this.colour, this.distance, 0);
	} 

	/**
	*	Draw the moon again, updating based on the angle passed.
	*
	*	The angle is updated using the moon's set velocity. The
	*	moon's angle is updated relative to its planet. If the 
	*	moon has no velocity, the angle is set to 0.
	*
	*	The moon's distance has the size of the sun deducted from
	*	it because it orbits a planet rather than the sun like 
	*	the planets do. 
	*/ 
	public void move() {
		this.solarSystem.drawSolarObjectAbout(this.planetAbout.distance, this.planetAbout.angle, 
												this.diameter, 
												this.colour, 
												this.distance - this.sunSize, 
												this.angle = (this.velocity != 0) ? (this.angleIncrement/this.velocity)+this.angle : 0);
	}
}