abstract class SpaceObject {
	int sunSize = 30;
	double angleIncrement = 0.5;

	double distance, angle, diameter, velocity; 
	String colour;
	SolarSystem solarSystem;

	/** 
	*	Create a SpaceObject that has upscaled diameters and
	*	distances within. Distances, diameters and velocities 
	*	are inputted in relation to the Earth's distance, 
	*	diameter and velocity (which are all 1).
	**/ 
	public SpaceObject(SolarSystem solarSystem, double distance, double diameter, double velocity, String colour) {
		this.solarSystem = solarSystem;
		this.angle = Math.random() * 360; 
		this.velocity = velocity;
		this.colour = colour;

		/**
		*	Scale the distances and diameters up to pixel sizes.
		*	Notice that the distance is increased to accommodate 
		*	for the sun
		**/
		this.diameter = (double)Math.round(((diameter * 10) * 1) / 1); 
		this.distance = (double)Math.round(((distance * 45) * 1) / 1) + ((distance > 0) ? this.sunSize : 0); 

	}

	/**
	*	To be implemented by subclasses. Implemented differently
	*	in each as the sun is drawn in the same place at all times,
	*	planet just updates its angle, and the moons update their
	*	angle relative to their planet
	**/
	abstract public void move();

}