import javax.swing.*;
import java.awt.*;
import java.util.*;

public class SmartSquare extends GameSquare 
{
	private boolean clicked = false; 
	private boolean thisSquareHasBomb = false;
	private SmartSquare[] adjacent = new SmartSquare[9]; 

	public static final int MINE_PROBABILITY = 20;

	public SmartSquare(int x, int y, GameBoard board)
	{
		super(x, y, "images/blank.png", board);

		Random r = new Random();
		thisSquareHasBomb = (r.nextInt(MINE_PROBABILITY) == 0);
	}

	public void clicked()
	{
		this.clicked = true;
		if(hasBomb())
			setImage("images/bomb.png"); 
		else 
			setImage("images/" + bombSweep(0, this.xLocation + 1, this.yLocation + 1, this.xLocation - 1, this.yLocation - 1) + ".png");
	}

	public int bombSweep(int bombs, int maxX, int maxY, int currentX, int currentY)
	{
		SmartSquare square = (SmartSquare)board.getSquareAt(currentX, currentY);

		/**
		* 1. Count bombs, save adjacent squares
		* Only want to check for bombs if the square we're on is actually a square
		* Also need to add selected square to an array of adjacent squares for traversal
		* later. 
		**/
		if(square instanceof SmartSquare) {
			if(square.hasBomb()) 
				bombs += 1; 
			// Add square to adjacent array (each x/y coord maps to a unique 0-8 array index)
			// This is so that if we have to we can traverse their adjacent squares (and recursively so)
			adjacent[((currentX - (maxX - 2)) * 3) + (currentY - (maxY - 2))] = square; 
		} 

		/**
		* 2. Traverse more squares if needed, return final bomb count
		* If we're on the last square, just return the bomb count and check adjacent 
		* squares if there's no bombs surrounding the selection
		*/
		if(currentX == maxX && currentY == maxY) {
			SmartSquare[] tempAdjacent = new SmartSquare[9];

			// Copy adjacent squares to temp variable and then 
			// clear main adjacent squares array
			for (int i=0; i < 9; i++) {
				tempAdjacent[i] = adjacent[i];
				adjacent[i] = null; 
			}

			// No bombs surrounding our square? Traverse and reveal adjacent squares & their bomb adjacency counts
			if(bombs == 0) {
				// Need to check if each adjacent square has bombs
				for (int i=0; i < 9; i++) {
					// Check if adjacent square is actually a square and not a boundary, and check if it has been clicked already
					if(tempAdjacent[i] instanceof SmartSquare && !tempAdjacent[i].clicked) {
						if(!tempAdjacent[i].hasBomb()) {
							tempAdjacent[i].clicked = true; 
							tempAdjacent[i].setImage("images/" + bombSweep(0, tempAdjacent[i].xLocation + 1, tempAdjacent[i].yLocation + 1, tempAdjacent[i].xLocation - 1, tempAdjacent[i].yLocation - 1) + ".png");
						}
					}
				}
			} 

			// Return final total number of bombs surrounding selected square
			return bombs; 
		}

		/**
		* 3. Traverse around our clicked square and count bombs
		* Traversing around the current square, done column by column:
		* If at the end of an X column, we need to increment the X position 
		* and reset the Y position.
		**/
		if((currentX == maxX - 2 || currentX == maxX - 1) && currentY == maxY)
			return bombSweep(bombs, maxX, maxY, ++currentX, currentY - 2);

		/**
		* Need to then traverse an X column
		**/
		if(currentX <= maxX && currentY <= maxY) 
			return bombSweep(bombs, maxX, maxY, currentX, ++currentY);

		// Return current total number of bombs surrounding selected square
		return bombs;
	}

	public boolean hasBomb()
	{
		return thisSquareHasBomb; 
	}
}
